@@ -8,7 +8,8 @@ from .interpolation import interp_hybrid_to_pressure, interp_sigma_to_hybrid, in
 from .meteorology import (dewtemp, heat_index, relhum, relhum_ice, relhum_water,
                           actual_saturation_vapor_pressure, max_daylight,
                           psychrometric_constant, saturation_vapor_pressure,
-                          saturation_vapor_pressure_slope, delta_pressure)
+                          saturation_vapor_pressure_slope, delta_pressure,
+                          dpres_plev)
 from .spherical import decomposition, recomposition, scale_voronoi
 from .stats import eofunc, eofunc_eofs, eofunc_pcs, eofunc_ts, pearson_r
 # bring all functions from geocat.f2py into the geocat.comp namespace
